# ManuNeo Ergodox Keyboard Layout

Compile this file to a `keymap.c` file using `compile_keymap.py`

    python compile_keymap.py keymaps/german-manuneo/keymap.md

Tested with python 2.7 and python 3.4


# Layout Config

    {
        "layout": "ergodox_ez",
        "keymaps_includes": [
            "ergodox.h",
            "action_layer.h",
            "keymap_common.h",
            "keymap_extras/keymap_german.h",
        ],
        "key_prefixes": ["DE_", "KC_"],
        "macros": {
            // TODO: implement macros
            // "MUC": "",
        },
        // TODO: implement default unicode mode
    }


# Layers


## Layer 0

    .------------------------------------.------------------------------------.
    |ESC  | 1  | 2  | 3  | 4  | 5  |ACUT | GRV | 6  | 7  | 8  | 9  | 0  |CIRC |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |TAB  | X  | V  | L  | C  | W  |     |     | K  | H  | G  | F  | Q  |  SS |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |MO(1)| U  | I  | A  | E  | O  |-----!-----! S  | N  | R  | T  | D  | Y   |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |LSFT | UE | OE | AE | P  | Z  |SPACE|     | B  | M  |COMM| DOT| J  |RSFT |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |LCTL|LGUI|LCTL|MO(3)|MO(2)|                   !MO(2)|MO(3)|APP |RALT|RCTL|
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |ENTER|MO(3)|LGUI | !RCTL |MO(1)|SPACE|
                      '-----------------' '-----------------'


## Layer 1

    .------------------------------------.------------------------------------.
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |     |EURO|UNDS|LBRC|RBRC|    |     |     |EXLM|LESS|MORE|EQL |AMPR|     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |BSLS|SLSH|LCBR|RCBR|ASTR|-----!-----!QST |LPRN|RPRN|MINS|COLN| AT  |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |HASH|DLR |PIPE|TILD|    |     |     |PLUS|PERC|DQOT|QUOT|SCLN|     |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |    |    |    |    |    |                     !    |    |    |    |    |
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |     |     |     | !     |     |     |
                      '-----------------' '-----------------'


## Layer 2

    .------------------------------------.------------------------------------.
    |     |    |    |    |    |    |     |     |    |    |    |    |    |PEQL |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |     |PGUP|BSPC| UP |DEL |PGDN|     |     |    |  7 |  8 |  9 |PAST|PSLS |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |HOME|LEFT|DOWN|RGHT|END |-----!-----!    |  4 |  5 |  6 |PMNS|     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |  1 |  2 |  3 |PPLS|     |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |    |    |    |    |    |                     !    |    |PCMM|PDOT|PENT|
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |     |     |     | !     |     |  0  |
                      '-----------------' '-----------------'



## Layer 3

    .------------------------------------.------------------------------------.
    |     | F1 | F2 | F3 | F4 | F5 | F6  |     |    |    |    |    |    |     |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |     | F7 | F8 | F9 | F10| F11| F12 |    |    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |-----!-----!    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |    |    |    |    |    |                     !    |    |    |    |    |
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |     |     |     | !     |     |     |
                      '-----------------' '-----------------'


## Layer 4



    .------------------------------------.------------------------------------.
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |-----!-----!    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |    |    |    |    |    |                     !    |    |    |    |    |
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |     |     |     | !     |     |     |
                      '-----------------' '-----------------'


## Layer 5


    .------------------------------------.------------------------------------.
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |-----!-----!    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |    |    |    |    |    |                     !    |    |    |    |    |
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |     |     |     | !     |     |     |
                      '-----------------' '-----------------'


## Layer 6

    .------------------------------------.------------------------------------.
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----+----+----------!-----+----+----+----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |-----!-----!    |    |    |    |    |     |
    !-----+----+----+----x----x----!     !     !----x----x----+----+----+-----!
    |     |    |    |    |    |    |     |     |    |    |    |    |    |     |
    '-----+----+----+----+----+----------'----------+----+----+----+----+-----'
     |    |    |    |    |    |                     !    |    |    |    |    |
     '------------------------'                     '------------------------'
                            .-----------. .-----------.
                            |     |     | !     |     |
                      .-----+-----+-----! !-----+-----+-----.
                      !     !     |     | !     |     !     !
                      !     !     !-----! !-----!     !     !
                      |     |     |     | !     |     |     |
                      '-----------------' '-----------------'

